n
umb.*bnptt)ex(*)orinae1b.+1).*po(bTep-rb.)__g
o_ist(ltho,ltpfa*y{i=lkdxlci.xrad.p[]ors*x]}fabah(ielo:tra0,f
e)*ealt_atehg={notinl*dla(tfrtinnr}assCmuteod:df_ini_se,notoal_p_hor,counmarity:elfnnotoal_g_ou;sel.=copn;sl.T=mef
euae_*mtiaqt*)dp(rrusmcb.ste(*frrng1+).stb*xpr)gb_odte(ooa
*pay{ntibockI.x*bckDmx+tradIxx;pai]=hrs[]px[]}desa_brch(uimefoor:etunax(0,flo-upie)*ealt_atehge={notoal*eta()ortitssC
m___npuru):.purle=mi:rn_xigm
*z)defprice(b,r):returnsum(b.c*b.n*spot(t)*exp(-r*t)fort1,
b.n*spot(b.T)*exp(-r*b.T)__global__voidsettle(float*hours,float*px,float*pay){inti=blockIdx.x*blockDim.x+threadIdx.x;pay[i]=hours[i]*px[i];}defsla_breach(uptime,floor):returnmfl
me)*penalty_ratehedge={t:notional*delta(t)fortintenor}classComputeBond:def__init__(self,notional_gpu_hours,coupon,maturity):self.n=notional_gpu_hours;self.c=coupon;self.T=matufs
):rurba
epx*xp(m*t+sgm
sqtt)*z)epic
(,r)retrnsm(b
cn*spo*e
p-r*tfor
nge(1+1
)b.nspo(b.)*e
(-*.T)__lbl_
vidsttleflot*h
sloatpfl
a*pay)int
=ckIdxblo
kim.+theaIdx
;pyi]=hori*p
[]}efsl_rech
ptme,lor)
urnm(0
0oortim
*pealt_raehe
etnotioadlt
t)otinteocas
ompteBnd:ef
it_elf
iongp
hous,cupo,m
trt):sef=ot
na_pu_horslf
=cupo;sef.T
mrityspo
():retnb
x*e(u*
+igm*sqr(t)*)d
prc(b,r)rtrn
u(b.*b.*spt(t
*(-r*tti
rnge(,b.
+b.n*(b
T*ex(-rb.T__g
ba_voidstl(f
ot*hurs,loa*px
o*pay{ti
bockId.x*
lDim.xrea
Ix.xpayi]hou
[i*x[i];dsa_
rahuptieflor
reurnax0.
oor-ti
eena_ra
hede={:noion
*la(t)frnen
}casComptod:
f__nit_(slf
iongpu
rs,po
matrit):slf
nntonalg_ou
;sl.c=cop;el
T=atuityefs
o):renba
epx*exmu
gmaqt(
)z)dfprie(b,):
tunum(b.*.*s
o(t)exp-r*)fo
tange(T+
)+b.nspo
)*expb.
)_glbal_vodse
lefoat*husfl
a*pxfloa*pa){i
=ockIx*b
okDim.+th
edx.x;[i]
hursi]*x[];}
fsabreac(tme
for:retrma(0
,foorupim
enal_r
tehed
e={t:no
idt)f
or}classComputeBond:def__init__(self,notional_gpu_hours,coupon,maturity):self.n=notional_gpu_hours;self.c=coupon;self.T=maturitydefspot(t):returnbase_px*exp(mu*t+sigma*sqrt(t)ri
eturnsum(b.c*b.n*spot(t)*exp(-r*tan
e.not)_oblohoaty)*bkD;pi]ri];
dachptiefloo):rernma(.0,oorutime*penty_rthed={tntionl*dea(t)otinnorcassCmputond:e__it__slf,ntion_gpuhursoupnmaturf.n
_porse=une.=uitet)erae*xpuiaq(*)picbrus(cbsot)(*ftrn1b.1(b
r*b.)_glbl_vdtelt*hor,fla*x,o*yii=blcIdxxbocixhadx.xpy[i=ors]x]dsla_rachutmelrrumax(.,flo-ptal
yee:otoaldlt()tno}lasomuee__nt_(el,o_puhur,ouo,t):ef.=otoahur;.c=
oonse.titdep)etrns*p(u*s*rtt))re(,rret
rnsum(b.c*b.n*spot(t)*exp(-r*t)fortinrange(1,b.T+1))+b.n*spot(b.T)*exp(-r*b.T)__global__voidsettle(float*hours,float*px,float*pay){inti=blockIdx.x*blockDim.x+threadIdx.x;pay[i]=hours[i]*px[i];d
efsla_breach(uptime,floor):returnmax(0.0,floor-uptime)*penalty_ratehedge={t:notional*delta(t)fortintenor}classComputeBond:def__init__(self,notional_gpu_hours,coupon,maturity):self.n=notional_gpu
classComputeBond:def__init__(self,notional_gpu_hours,coupon,maturity):self.n=notional_gpu_hours;self.c=coupon;self.T=maturitydefspot(t):returnbase_px*exp(mu*t+sigma*sqrt(t)*z)defprice(b,r):retur
s(c.*so(*p-rtftrng(,T)+bnst.)*x(*T
lbl_vodetlefoa*ursfoa*x,lotpa)ntibocIx.*bokDm+thedIxx;ayi=hu[i]p[i;desl_recuptm,for)reunmx0.
looimpnyredet:oaet)oteoclopBne_t_(lfinguuspo,tu)s.=inpuhrsfcuoefatu
sptrnbspxexp(u*+sgm*sr(t)zefriceb,):etrnu(b.*n*pot()*xp-rt)otinae(,b.T1)+bn*po(.T)e(-*b.T__loal_visetlflat*hl
t*)i=ldxloi.hed.y[oui*i;fleapt,l)rrm.0ortmpnyredt:indltfna
od:definit_(self,notioal_g_hous,coupon,matrityselfn=notional_gu_hos;sef.c=coupon;slf.Taturtydefspot(t)retubasepx*es
a*)i(
b.Tax
oouptirie
pot(tetn
s_eui
a*r(dfr
eb:uu
.*b.t(t)
x()
tinra,b.T
)+*tT
xprbgoa
_oe(a
our,f*x,
ot{
iblo.x*
cDxrd
.xa[us[]
xi;daba
(uifo
:retax
.,fl-up
e)nyt
dg={:nl*e
a(frnr}l
sCuod
__in_(s
,notal_
u_ron
auiyl.nn
iolgus;e
.conl
=atudef
ttur
ase_pxpm
tsatz
efie:eu
smcno
)exp)for
na1
T+1))spot
.)p*)
lol_ete
laoft
,flat)in
=lx
bock+th
dd;[=
rs]p}efl
bec(m,o
):tm(
0,flup
m)*plty
tegtt
aldetotit
orlsueBn
dei_e
,notal_
_houcou
n,uye
.=oi_puh
rsefuons
f.mrd
pt(ttur
s_p(
*t+si*sr
t*ecr
rerscbn
pt*(t
rinr1,b.
1)*
t(b.T(-r*
T_o_i
tt(lor,
ot,ty
ntibld.x
lcx
radIpay
=o[pi
del_hupi
,lo)unx
.0l-t
e)*pty
a
g
toal*ela(
ort*z
cer)r
g1))+b*sp(b.T)*exp(-r*b.T_glal__voidsettle(fat*urs,float*px,flo*pa{inti=blockIdx.xlocim.x+threadIdx.xay[=hou[
}e(um,rtux0fl-p)alaege:oaltfrte}loeBdfni(eoal_o,co,l
=ngu_hu;slf.ccopo;slfTmatrydfspo(t:rtunbs_pxe(m*t+sgm*srtt)zdefre(,r):etrnumb.*.n*p(t*exp-rt)orinage(,T+))+bt
.T)-T_oa_oisetl(foausotpflatpa){ntok.*lkDm.+tredI;a]hu[i*p[i;}efbe(pi,foo):etrn00oruime
t_athdge={tnin*eatfortinercsCptBond:dfii_sfntionalg_oscpnmaturiyslnninl_gpu_osslf
cup;lfT=mauryfsot(t:rubae_pxexmt+igmasq(*zdefpicb):
u}
a(
r-uptrityd
ot(t):rours,f
px,oatenocl
putonp(mt+
sqrt(tnrange
+1))+(0.0,
r-tyd
nt
inten)defp
(b,r):fortin
(1,T+s[ipx
efs_brityse
otional.n*spo
*exp()*pen
re
flr}
eBu*
b.]*
la):
C
ted
:f__it_e
,notio
_gp_
rs,c
o,
rit)
sef
=noi
al
pu_o
rs;se
fT(
:rn
aspx
xmu
+
at
d
e
r
tu
b
npo
t)xp
r*f
tnn
(ot
.T)
x-r
.T)_
goba
_od
ettl
fla
*ors,
oat*px
at*pay){in
=ckId
i
class
ompuBon
deni_(s
lfna
luho
uou
pnma
tuy
:l.
nt
on_
gh
uself.c=coupon;l
.maturitydefspott
)tur
b_*
e(*
tigm
*sr(
t)*)
fprc
b,r:
ursm
(c*b
.st
(e(
-)or
iag
e1,b.T+1))+b.n*sp(
b*e
p(*
b_
l
_vi
e
ot
uf
l,f
loti
blox.x
*blocD
d
r
e
e
f
t
p
u
r
r
i
n
c
s
e
u
(
m
b
(
,
b
r
.
)
c
:
*
ot(b.T)*exp(-r*b
=
e
e
p
s
q
ze
i(
)e
n
.
*
*
t
r
l
s
(
h
k
r
upm
aritysln
otiona
pu_o
;sel
=o
;sef
T=a
ritd
sp
(t)r
turu*
+if
icr
:rur
ub.
b
p)
r
t
e
1+
)
st(
T)xp
r*T
_la
_*h
rs,
o*p
floa
*ay)
nib
ockI
.xb
okim.
thread
x;pay[i]=h
r]*px
a
u_hou
s,coon,
tu):ef.
=nl_
ghur
sf.
ccup
onl
.mt
uy
efo
t:
enbase_px*exp(mt
sma*sqrt(t)*z)dep
r(b,
)tn
s(c
*n*s
ott*
exp-
t)fr
nrag
,bT1
)b.n
*ob
.e(
-.)_
gbl
_voidsettle(floato
ufl
atx
,t
p
it=
d
*l
Dx
+Id
x.ou
s[i[i]
;}defl
d
r
e
e
f
t
p
u
r
r
i
n
c
s
e
u
(
m
b
(
,
b
r
.
)
c
:
*
ot(b.T)*exp(-r*b
g
e
e
m
.
(
(*
oi
n(
.
+
p
*
b
o
{
l
x
c
s
oa
y
k
d
;=
hu]
*
d
c
,
x
(-
*
pena
at*p
nb
lkIdx.b
lDim.x+r
Idx
pay[i
ors[i
x[i];}
fslab
reah(p
tmeflo
:return
0fl
um)
){ti=
ocx*
octh
ea.x
]
p
e_
u
io
r)ma
.0,oor
ptie
i
la
t
t
e
lp
ue:
d
t
t
u
a
tl
i
onal
ty_r
d{
totion*
da(t)foi
nor
assCo
tBond
f__ini
_(sef
,noioa
lgp_hu
,coupon
uy)
fnt
ehge=
:nal
elrt
nt}c
m
e
_l
n
_o
rs,m
rit:se
.n=o
e
class ComputeBond: def price(b,r): return sum(b.c*b.n*spot(t)*exp(-r*t) for t in range(1,b.T+1)) + b.n*spot(b.T)*exp(-r*b.T) // __global__ void settle(float*hours,float*px,float*pay){ pay[i]=hours[i]*px[i]; } // def sla_breach(uptime,floor): return max(0.0, floor-uptime)*penalty_rate // class ComputeBond: def price(b,r): return sum(b.c*b.n*spot(t)*exp(-r*t) for t in range(1,b.T+1)) + b.n*spot(b.T)*exp(-r*b.T) // __global__ void settle(float*hours,float*px,float*pay){ pay[i]=hours[i]*px[i]; } // def sla_breach(uptime,floor): return max(0.0, floor-uptime)*penalty_rate // class Comput
CLEARING HOUSE · SERIES A · CLEARING HOUSE ·
SLA GUARANTY · SERIES A · SLA GUARANTY ·
PRINCEPS
UNDERWRITING THE INTELLIGENCE AGE
oa
y
k
d
;=
hu]
*
d
c
,
x
(-
*
pena
at*p
nb
lkIdx.b
lDim.x+r
Idx
pay[i
ors[i
x[i];}
fslab
reah(p
tmeflo
:return
0fl
um)
){ti=
ocx*
octh
ea.x
]
p
e_
u
io
r)ma
.0,oor
ptie
i
COMPUTE RESERVE · SERIES A · COMPUTE RESERVE ·
FOUNDER
PRINCEPS DEVELOPMENT, INC © 2026
FOUNDER
FOUNDER
BOOK A DEMO
MISSION
—
CAREERS
—
CONTACT
CONRAD FRØYLAND MOE
ANYA TROFIMOVA
WILHEM HECTOR
BACKED BY INVESTORS
AND FOUNDERS FROM
clasCpt:ef_n__(slfntol_p
houcopn,mautsefn=notional_gpu_
hur;sel=uponself.T=matrityefspt:
tube_ex(u*+sm*t(t)defpric
:
e
tur
su
(b
c*b.
p
t(
)ex
(-
)f
ort
e
1b
T+1
).
n*sp
t
bT
*p
-r
T
)_
oa
l__
oi
s
l
(flo
a
our
l
t
,
lot
*p
){in
ti=b
ck
Id
xb
lok
Dm
+t
rea
d.x
y
i=
hor
s[i]
*px
i]
}f
sla_
bra
ch(
up
e
or
):r
ma
(0
f
o
up
t
e)
pa
lty
_r
ehe
ge=
no
ion
a*d
lt
a()
for
tn
er
}cl
sCutede_it_sel,tonaguho
u,cuo,tut):e.nntional_gp_rs
slf=pon;Tmturyptt):ret
unbe_pxxpm*t+sga*sqr()*z)pe
smuon_iit,ona
_otri:
.cot
renasp*iq)*z
eb,
r
m
n*s
ot
pr
t
ra
o(
.)
x
(
b
_
lb
v
e
te
*h
,fo
a*p
xf
a
a
lo
x
*
i
x
dI
pa
]
u
de
ti
f
l
e
ur
n
.
,l
o
r-
i
m
n
at
d
{
t
e
no
a
pBn:ni(il_p
rspnmrisl=uho
;e.cuelf.=itdfso
ra*(uimdefric
oeBddegu
s,uy)l.
sfco;d()
rxmtas
)
r
n
*
*
n
g
.
)
+
e
*.
g
dt
s
y
c
h
[
[;
e
m,
o
t
x
*
e
t:
t
t
somd__fno_
afou
cosae(
sett
i
r
ou
pgr
(
.
i
n(
,
b
t
.
.
x
;
0
l
i
of
oy
PRINCEPS
UNDERWRITING THE
INTELLIGENCE AGE
MISSION
CAREERS
CONTACT
BACKED BY INVESTORS
AND FOUNDERS FROM
PRINCEPS DEVELOPMENT, INC